@@ -39,6 +39,6 @@ You can export, migrate or edit the config.`,
 	},
 }
 
-func init() { //nolint:gochecknoinits
-	rootCmd.AddCommand(configCmd)
+func init() {
+	RootCmd.AddCommand(configCmd)
 }
