@@ -22,6 +22,6 @@ var disableCmd = &cobra.Command{
 	},
 }
 
-func init() { //nolint:gochecknoinits
+func init() {
 	RootCmd.AddCommand(disableCmd)
 }
