@@ -3,7 +3,6 @@ package engine
 import (
 	"strings"
 	"sync"
-	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
@@ -39,19 +38,19 @@ const (
 
 // Block defines a part of the prompt with optional segments
 type Block struct {
-	Type      BlockType      `json:"type,omitempty"`
-	Alignment BlockAlignment `json:"alignment,omitempty"`
-	Segments  []*Segment     `json:"segments,omitempty"`
-	Newline   bool           `json:"newline,omitempty"`
-	Filler    string         `json:"filler,omitempty"`
-	Overflow  Overflow       `json:"overflow,omitempty"`
+	Type      BlockType      `json:"type,omitempty" toml:"type,omitempty"`
+	Alignment BlockAlignment `json:"alignment,omitempty" toml:"alignment,omitempty"`
+	Segments  []*Segment     `json:"segments,omitempty" toml:"segments,omitempty"`
+	Newline   bool           `json:"newline,omitempty" toml:"newline,omitempty"`
+	Filler    string         `json:"filler,omitempty" toml:"filler,omitempty"`
+	Overflow  Overflow       `json:"overflow,omitempty" toml:"overflow,omitempty"`
 
 	// Deprecated: keep the logic for legacy purposes
-	HorizontalOffset int `json:"horizontal_offset,omitempty"`
-	VerticalOffset   int `json:"vertical_offset,omitempty"`
+	HorizontalOffset int `json:"horizontal_offset,omitempty" toml:"horizontal_offset,omitempty"`
+	VerticalOffset   int `json:"vertical_offset,omitempty" toml:"vertical_offset,omitempty"`
 
-	MaxWidth int `json:"max_width,omitempty"`
-	MinWidth int `json:"min_width,omitempty"`
+	MaxWidth int `json:"max_width,omitempty" toml:"max_width,omitempty"`
+	MinWidth int `json:"min_width,omitempty" toml:"min_width,omitempty"`
 
 	env                   platform.Environment
 	writer                *ansi.Writer
@@ -77,9 +76,6 @@ func (b *Block) InitPlain(env platform.Environment, config *Config) {
 }
 
 func (b *Block) executeSegmentLogic() {
-	if b.env.Flags().Debug {
-		return
-	}
 	if shouldHideForWidth(b.env, b.MinWidth, b.MaxWidth) {
 		return
 	}
@@ -133,14 +129,18 @@ func (b *Block) RenderSegments() (string, int) {
 		if !segment.Enabled && segment.style() != Accordion {
 			continue
 		}
+
 		if colors, newCycle := cycle.Loop(); colors != nil {
 			cycle = &newCycle
 			segment.colors = colors
 		}
+
 		b.setActiveSegment(segment)
 		b.renderActiveSegment()
 	}
+
 	b.writeSeparator(true)
+
 	return b.writer.String()
 }
 
@@ -150,7 +150,11 @@ func (b *Block) renderActiveSegment() {
 	case Plain, Powerline:
 		b.writer.Write(ansi.Background, ansi.Foreground, b.activeSegment.text)
 	case Diamond:
-		b.writer.Write(ansi.Transparent, ansi.Background, b.activeSegment.LeadingDiamond)
+		background := ansi.Transparent
+		if b.previousActiveSegment != nil && b.previousActiveSegment.hasEmptyDiamondAtEnd() {
+			background = b.previousActiveSegment.background()
+		}
+		b.writer.Write(background, ansi.Background, b.activeSegment.LeadingDiamond)
 		b.writer.Write(ansi.Background, ansi.Foreground, b.activeSegment.text)
 	case Accordion:
 		if b.activeSegment.Enabled {
@@ -266,29 +270,3 @@ func (b *Block) getPowerlineColor() string {
 	}
 	return b.previousActiveSegment.background()
 }
-
-func (b *Block) Debug() (int, []*SegmentTiming) {
-	var segmentTimings []*SegmentTiming
-	largestSegmentNameLength := 0
-	for _, segment := range b.Segments {
-		var segmentTiming SegmentTiming
-		segmentTiming.name = string(segment.Type)
-		segmentTiming.nameLength = len(segmentTiming.name)
-		if segmentTiming.nameLength > largestSegmentNameLength {
-			largestSegmentNameLength = segmentTiming.nameLength
-		}
-		b.env.DebugF("Segment: %s", segmentTiming.name)
-		start := time.Now()
-		segment.SetEnabled(b.env)
-		segment.SetText()
-		segmentTiming.active = segment.Enabled
-		if segmentTiming.active || segment.style() == Accordion {
-			b.setActiveSegment(segment)
-			b.renderActiveSegment()
-			segmentTiming.text, _ = b.writer.String()
-		}
-		segmentTiming.duration = time.Since(start)
-		segmentTimings = append(segmentTimings, &segmentTiming)
-	}
-	return largestSegmentNameLength, segmentTimings
-}
