@@ -14,7 +14,16 @@ import (
 	mock2 "github.com/stretchr/testify/mock"
 )
 
-func renderTemplateNoTrimSpace(env *mock.MockedEnvironment, segmentTemplate string, context interface{}) string {
+const (
+	homeDir        = "/home/someone"
+	homeDirWindows = "C:\\Users\\someone"
+	fooBarMan      = "\\foo\\bar\\man"
+	abc            = "/abc"
+	abcd           = "/a/b/c/d"
+	cdefg          = "/c/d/e/f/g"
+)
+
+func renderTemplateNoTrimSpace(env *mock.MockedEnvironment, segmentTemplate string, context any) string {
 	found := false
 	for _, call := range env.Mock.ExpectedCalls {
 		if call.Method == "TemplateCache" {
@@ -29,6 +38,7 @@ func renderTemplateNoTrimSpace(env *mock.MockedEnvironment, segmentTemplate stri
 	}
 	env.On("Error", mock2.Anything)
 	env.On("Debug", mock2.Anything)
+	env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 	tmpl := &template.Text{
 		Template: segmentTemplate,
 		Context:  context,
@@ -41,15 +51,10 @@ func renderTemplateNoTrimSpace(env *mock.MockedEnvironment, segmentTemplate stri
 	return text
 }
 
-func renderTemplate(env *mock.MockedEnvironment, segmentTemplate string, context interface{}) string {
+func renderTemplate(env *mock.MockedEnvironment, segmentTemplate string, context any) string {
 	return strings.TrimSpace(renderTemplateNoTrimSpace(env, segmentTemplate, context))
 }
 
-const (
-	homeDir        = "/home/someone"
-	homeDirWindows = "C:\\Users\\someone"
-)
-
 func TestParent(t *testing.T) {
 	cases := []struct {
 		Case                string
@@ -528,7 +533,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 			Style:               AgnosterShort,
 			Expected:            ".. > bar > man",
 			HomePath:            homeDirWindows,
-			Pwd:                 homeDirWindows + "\\foo\\bar\\man",
+			Pwd:                 homeDirWindows + fooBarMan,
 			GOOS:                platform.WINDOWS,
 			PathSeparator:       "\\",
 			FolderSeparatorIcon: " > ",
@@ -676,7 +681,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 			Style:               AgnosterShort,
 			Expected:            "~ > .. > bar > man",
 			HomePath:            homeDirWindows,
-			Pwd:                 homeDirWindows + "\\foo\\bar\\man",
+			Pwd:                 homeDirWindows + fooBarMan,
 			GOOS:                platform.WINDOWS,
 			PathSeparator:       "\\",
 			FolderSeparatorIcon: " > ",
@@ -686,7 +691,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 			Style:               AgnosterShort,
 			Expected:            "~ > foo > bar > man",
 			HomePath:            homeDirWindows,
-			Pwd:                 homeDirWindows + "\\foo\\bar\\man",
+			Pwd:                 homeDirWindows + fooBarMan,
 			GOOS:                platform.WINDOWS,
 			PathSeparator:       "\\",
 			FolderSeparatorIcon: " > ",
@@ -773,30 +778,30 @@ func TestFullAndFolderPath(t *testing.T) {
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", Expected: "/"},
 		{Style: Full, Pwd: "/", Expected: "/"},
 		{Style: Full, Pwd: homeDir, Expected: "~"},
-		{Style: Full, Pwd: homeDir + "/abc", Expected: "~/abc"},
-		{Style: Full, Pwd: homeDir + "/abc", Expected: homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", Expected: "/a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, Expected: "~/abc"},
+		{Style: Full, Pwd: homeDir + abc, Expected: homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, Expected: abcd},
 
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "~"},
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "/home|someone", DisableMappedLocations: true},
-		{Style: Full, FolderSeparatorIcon: "|", Pwd: homeDir + "/abc", Expected: "~|abc"},
-		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/a/b/c/d", Expected: "/a|b|c|d"},
+		{Style: Full, FolderSeparatorIcon: "|", Pwd: homeDir + abc, Expected: "~|abc"},
+		{Style: Full, FolderSeparatorIcon: "|", Pwd: abcd, Expected: "/a|b|c|d"},
 
-		{Style: Folder, Pwd: "/", Expected: "/"},
-		{Style: Folder, Pwd: homeDir, Expected: "~"},
-		{Style: Folder, Pwd: homeDir, Expected: "someone", DisableMappedLocations: true},
-		{Style: Folder, Pwd: homeDir + "/abc", Expected: "abc"},
-		{Style: Folder, Pwd: "/a/b/c/d", Expected: "d"},
+		{Style: FolderType, Pwd: "/", Expected: "/"},
+		{Style: FolderType, Pwd: homeDir, Expected: "~"},
+		{Style: FolderType, Pwd: homeDir, Expected: "someone", DisableMappedLocations: true},
+		{Style: FolderType, Pwd: homeDir + abc, Expected: "abc"},
+		{Style: FolderType, Pwd: abcd, Expected: "d"},
 
-		{Style: Folder, FolderSeparatorIcon: "|", Pwd: "/", Expected: "/"},
-		{Style: Folder, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "~"},
-		{Style: Folder, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "someone", DisableMappedLocations: true},
-		{Style: Folder, FolderSeparatorIcon: "|", Pwd: homeDir + "/abc", Expected: "abc"},
-		{Style: Folder, FolderSeparatorIcon: "|", Pwd: "/a/b/c/d", Expected: "d"},
+		{Style: FolderType, FolderSeparatorIcon: "|", Pwd: "/", Expected: "/"},
+		{Style: FolderType, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "~"},
+		{Style: FolderType, FolderSeparatorIcon: "|", Pwd: homeDir, Expected: "someone", DisableMappedLocations: true},
+		{Style: FolderType, FolderSeparatorIcon: "|", Pwd: homeDir + abc, Expected: "abc"},
+		{Style: FolderType, FolderSeparatorIcon: "|", Pwd: abcd, Expected: "d"},
 
 		// for Windows paths
-		{Style: Folder, FolderSeparatorIcon: "\\", Pwd: "C:\\", Expected: "C:\\", PathSeparator: "\\", GOOS: platform.WINDOWS},
-		{Style: Folder, FolderSeparatorIcon: "\\", Pwd: homeDirWindows, Expected: "~", PathSeparator: "\\", GOOS: platform.WINDOWS},
+		{Style: FolderType, FolderSeparatorIcon: "\\", Pwd: "C:\\", Expected: "C:\\", PathSeparator: "\\", GOOS: platform.WINDOWS},
+		{Style: FolderType, FolderSeparatorIcon: "\\", Pwd: homeDirWindows, Expected: "~", PathSeparator: "\\", GOOS: platform.WINDOWS},
 		{Style: Full, FolderSeparatorIcon: "\\", Pwd: homeDirWindows, Expected: "~", PathSeparator: "\\", GOOS: platform.WINDOWS},
 		{Style: Full, FolderSeparatorIcon: "\\", Pwd: homeDirWindows + "\\abc", Expected: "~\\abc", PathSeparator: "\\", GOOS: platform.WINDOWS},
 		{Style: Full, FolderSeparatorIcon: "\\", Pwd: "C:\\Users\\posh", Expected: "C:\\Users\\posh", PathSeparator: "\\", GOOS: platform.WINDOWS},
@@ -805,41 +810,41 @@ func TestFullAndFolderPath(t *testing.T) {
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", StackCount: 2, Expected: "2 /"},
 		{Style: Full, Pwd: "/", StackCount: 2, Expected: "2 /"},
 		{Style: Full, Pwd: homeDir, StackCount: 2, Expected: "2 ~"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: 2, Expected: "2 ~/abc"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: 2, Expected: "2 " + homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", StackCount: 2, Expected: "2 /a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: 2, Expected: "2 ~/abc"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: 2, Expected: "2 " + homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, StackCount: 2, Expected: "2 /a/b/c/d"},
 
 		// StackCountEnabled=false and StackCount=2
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", Template: "{{ .Path }}", StackCount: 2, Expected: "/"},
 		{Style: Full, Pwd: "/", Template: "{{ .Path }}", StackCount: 2, Expected: "/"},
 		{Style: Full, Pwd: homeDir, Template: "{{ .Path }}", StackCount: 2, Expected: "~"},
 
-		{Style: Full, Pwd: homeDir + "/abc", Template: "{{ .Path }}", StackCount: 2, Expected: homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", Template: "{{ .Path }}", StackCount: 2, Expected: "/a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, Template: "{{ .Path }}", StackCount: 2, Expected: homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, Template: "{{ .Path }}", StackCount: 2, Expected: abcd},
 
 		// StackCountEnabled=true and StackCount=0
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", StackCount: 0, Expected: "/"},
 		{Style: Full, Pwd: "/", StackCount: 0, Expected: "/"},
 		{Style: Full, Pwd: homeDir, StackCount: 0, Expected: "~"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: 0, Expected: "~/abc"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: 0, Expected: homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", StackCount: 0, Expected: "/a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: 0, Expected: "~/abc"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: 0, Expected: homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, StackCount: 0, Expected: abcd},
 
 		// StackCountEnabled=true and StackCount<0
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", StackCount: -1, Expected: "/"},
 		{Style: Full, Pwd: "/", StackCount: -1, Expected: "/"},
 		{Style: Full, Pwd: homeDir, StackCount: -1, Expected: "~"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: -1, Expected: "~/abc"},
-		{Style: Full, Pwd: homeDir + "/abc", StackCount: -1, Expected: homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", StackCount: -1, Expected: "/a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: -1, Expected: "~/abc"},
+		{Style: Full, Pwd: homeDir + abc, StackCount: -1, Expected: homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, StackCount: -1, Expected: abcd},
 
 		// StackCountEnabled=true and StackCount not set
 		{Style: Full, FolderSeparatorIcon: "|", Pwd: "/", Expected: "/"},
 		{Style: Full, Pwd: "/", Expected: "/"},
 		{Style: Full, Pwd: homeDir, Expected: "~"},
-		{Style: Full, Pwd: homeDir + "/abc", Expected: "~/abc"},
-		{Style: Full, Pwd: homeDir + "/abc", Expected: homeDir + "/abc", DisableMappedLocations: true},
-		{Style: Full, Pwd: "/a/b/c/d", Expected: "/a/b/c/d"},
+		{Style: Full, Pwd: homeDir + abc, Expected: "~/abc"},
+		{Style: Full, Pwd: homeDir + abc, Expected: homeDir + abc, DisableMappedLocations: true},
+		{Style: Full, Pwd: abcd, Expected: abcd},
 	}
 
 	for _, tc := range cases {
@@ -894,25 +899,25 @@ func TestFullPathCustomMappedLocations(t *testing.T) {
 		PathSeparator   string
 		Expected        string
 	}{
-		{Pwd: "/a/b/c/d", MappedLocations: map[string]string{"{{ .Env.HOME }}/d": "#"}, Expected: "#"},
-		{Pwd: "/a/b/c/d", MappedLocations: map[string]string{"/a/b/c/d": "#"}, Expected: "#"},
+		{Pwd: abcd, MappedLocations: map[string]string{"{{ .Env.HOME }}/d": "#"}, Expected: "#"},
+		{Pwd: abcd, MappedLocations: map[string]string{abcd: "#"}, Expected: "#"},
 		{Pwd: "\\a\\b\\c\\d", MappedLocations: map[string]string{"\\a\\b": "#"}, GOOS: platform.WINDOWS, PathSeparator: "\\", Expected: "#\\c\\d"},
-		{Pwd: "/a/b/c/d", MappedLocations: map[string]string{"/a/b": "#"}, Expected: "#/c/d"},
-		{Pwd: "/a/b/c/d", MappedLocations: map[string]string{"/a/b": "/e/f"}, Expected: "/e/f/c/d"},
-		{Pwd: homeDir + "/a/b/c/d", MappedLocations: map[string]string{"~/a/b": "#"}, Expected: "#/c/d"},
+		{Pwd: abcd, MappedLocations: map[string]string{"/a/b": "#"}, Expected: "#/c/d"},
+		{Pwd: abcd, MappedLocations: map[string]string{"/a/b": "/e/f"}, Expected: "/e/f/c/d"},
+		{Pwd: homeDir + abcd, MappedLocations: map[string]string{"~/a/b": "#"}, Expected: "#/c/d"},
 		{Pwd: "/a" + homeDir + "/b/c/d", MappedLocations: map[string]string{"/a~": "#"}, Expected: "/a" + homeDir + "/b/c/d"},
-		{Pwd: homeDir + "/a/b/c/d", MappedLocations: map[string]string{"/a/b": "#"}, Expected: homeDir + "/a/b/c/d"},
+		{Pwd: homeDir + abcd, MappedLocations: map[string]string{"/a/b": "#"}, Expected: homeDir + abcd},
 	}
 
 	for _, tc := range cases {
 		env := new(mock.MockedEnvironment)
 		env.On("Home").Return(homeDir)
 		env.On("Pwd").Return(tc.Pwd)
-		if tc.GOOS == "" {
+		if len(tc.GOOS) == 0 {
 			tc.GOOS = platform.DARWIN
 		}
 		env.On("GOOS").Return(tc.GOOS)
-		if tc.PathSeparator == "" {
+		if len(tc.PathSeparator) == 0 {
 			tc.PathSeparator = "/"
 		}
 		env.On("PathSeparator").Return(tc.PathSeparator)
@@ -921,6 +926,7 @@ func TestFullPathCustomMappedLocations(t *testing.T) {
 		}
 		env.On("Flags").Return(args)
 		env.On("Shell").Return(shell.GENERIC)
+		env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 		env.On("TemplateCache").Return(&platform.TemplateCache{
 			Env: map[string]string{
 				"HOME": "/a/b/c",
@@ -941,8 +947,39 @@ func TestFullPathCustomMappedLocations(t *testing.T) {
 	}
 }
 
+func TestPowerlevelMappedLocations(t *testing.T) {
+	cases := []struct {
+		Pwd             string
+		MappedLocations map[string]string
+		Expected        string
+	}{
+		{Pwd: "/Users/michal/Applications", MappedLocations: map[string]string{"~": "#"}, Expected: "#/Applications"},
+	}
+
+	for _, tc := range cases {
+		env := new(mock.MockedEnvironment)
+		env.On("Home").Return("/Users/michal")
+		env.On("Pwd").Return(tc.Pwd)
+		env.On("GOOS").Return(platform.DARWIN)
+		env.On("PathSeparator").Return("/")
+		env.On("Shell").Return(shell.GENERIC)
+		env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
+		path := &Path{
+			env: env,
+			props: properties.Map{
+				properties.Style: Powerlevel,
+				MappedLocations:  tc.MappedLocations,
+			},
+		}
+		path.setPaths()
+		path.setStyle()
+		got := renderTemplateNoTrimSpace(env, "{{ .Path }}", path)
+		assert.Equal(t, tc.Expected, got)
+	}
+}
+
 func TestFolderPathCustomMappedLocations(t *testing.T) {
-	pwd := "/a/b/c/d"
+	pwd := abcd
 	env := new(mock.MockedEnvironment)
 	env.On("PathSeparator").Return("/")
 	env.On("Home").Return(homeDir)
@@ -953,12 +990,13 @@ func TestFolderPathCustomMappedLocations(t *testing.T) {
 	}
 	env.On("Flags").Return(args)
 	env.On("Shell").Return(shell.GENERIC)
+	env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 	path := &Path{
 		env: env,
 		props: properties.Map{
-			properties.Style: Folder,
+			properties.Style: FolderType,
 			MappedLocations: map[string]string{
-				"/a/b/c/d": "#",
+				abcd: "#",
 			},
 		},
 	}
@@ -1315,16 +1353,16 @@ func TestGetPwd(t *testing.T) {
 		{MappedLocationsEnabled: true, Pwd: homeDir + "-test", Expected: homeDir + "-test"},
 		{MappedLocationsEnabled: true},
 		{MappedLocationsEnabled: true, Pwd: "/usr", Expected: "/usr"},
-		{MappedLocationsEnabled: true, Pwd: homeDir + "/abc", Expected: "~/abc"},
-		{MappedLocationsEnabled: true, Pwd: "/a/b/c/d", Expected: "#"},
+		{MappedLocationsEnabled: true, Pwd: homeDir + abc, Expected: "~/abc"},
+		{MappedLocationsEnabled: true, Pwd: abcd, Expected: "#"},
 		{MappedLocationsEnabled: true, Pwd: "/a/b/c/d/e/f/g", Expected: "#/e/f/g"},
 		{MappedLocationsEnabled: true, Pwd: "/z/y/x/w", Expected: "/z/y/x/w"},
 
 		{MappedLocationsEnabled: false},
-		{MappedLocationsEnabled: false, Pwd: homeDir + "/abc", Expected: homeDir + "/abc"},
+		{MappedLocationsEnabled: false, Pwd: homeDir + abc, Expected: homeDir + abc},
 		{MappedLocationsEnabled: false, Pwd: "/a/b/c/d/e/f/g", Expected: "#/e/f/g"},
-		{MappedLocationsEnabled: false, Pwd: homeDir + "/c/d/e/f/g", Expected: homeDir + "/c/d/e/f/g"},
-		{MappedLocationsEnabled: true, Pwd: homeDir + "/c/d/e/f/g", Expected: "~/c/d/e/f/g"},
+		{MappedLocationsEnabled: false, Pwd: homeDir + cdefg, Expected: homeDir + cdefg},
+		{MappedLocationsEnabled: true, Pwd: homeDir + cdefg, Expected: "~/c/d/e/f/g"},
 
 		{MappedLocationsEnabled: true, Pwd: "/w/d/x/w", Pswd: "/z/y/x/w", Expected: "/z/y/x/w"},
 		{MappedLocationsEnabled: false, Pwd: "/f/g/k/d/e/f/g", Pswd: "/a/b/c/d/e/f/g", Expected: "#/e/f/g"},
@@ -1341,12 +1379,13 @@ func TestGetPwd(t *testing.T) {
 		}
 		env.On("Flags").Return(args)
 		env.On("Shell").Return(shell.PWSH)
+		env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 		path := &Path{
 			env: env,
 			props: properties.Map{
 				MappedLocationsEnabled: tc.MappedLocationsEnabled,
 				MappedLocations: map[string]string{
-					"/a/b/c/d": "#",
+					abcd: "#",
 				},
 			},
 		}
@@ -1374,6 +1413,7 @@ func TestGetFolderSeparator(t *testing.T) {
 		env.On("PathSeparator").Return("/")
 		env.On("Error", mock2.Anything)
 		env.On("Debug", mock2.Anything)
+		env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 		path := &Path{
 			env: env,
 		}
@@ -1432,7 +1472,7 @@ func TestReplaceMappedLocations(t *testing.T) {
 		{Pwd: "/c/l/k/f", Expected: "f"},
 		{Pwd: "/f/g/h", Expected: "/f/g/h"},
 		{Pwd: "/f/g/h/e", Expected: "^/e"},
-		{Pwd: "/a/b/c/d", Expected: "#"},
+		{Pwd: abcd, Expected: "#"},
 		{Pwd: "/a/b/c/d/e", Expected: "#/e"},
 		{Pwd: "/a/b/c/d/e", Expected: "#/e"},
 		{Pwd: "/a/b/k/j/e", Expected: "e"},
@@ -1445,12 +1485,13 @@ func TestReplaceMappedLocations(t *testing.T) {
 		env.On("Shell").Return(shell.FISH)
 		env.On("GOOS").Return(platform.DARWIN)
 		env.On("Home").Return("/a/b/k")
+		env.On("DebugF", mock2.Anything, mock2.Anything).Return(nil)
 		path := &Path{
 			env: env,
 			props: properties.Map{
 				MappedLocationsEnabled: false,
 				MappedLocations: map[string]string{
-					"/a/b/c/d": "#",
+					abcd:       "#",
 					"/f/g/h/*": "^",
 					"/c/l/k/*": "",
 					"~/j/*":    "",
@@ -1461,3 +1502,71 @@ func TestReplaceMappedLocations(t *testing.T) {
 		assert.Equal(t, tc.Expected, path.pwd)
 	}
 }
+
+func TestSplitPath(t *testing.T) {
+	cases := []struct {
+		Case         string
+		GOOS         string
+		Relative     string
+		Root         string
+		GitDir       *platform.FileInfo
+		GitDirFormat string
+		Expected     Folders
+	}{
+		{Case: "Root directory", Root: "/", Expected: Folders{}},
+		{
+			Case:     "Regular directory",
+			Root:     "/",
+			Relative: "c/d",
+			GOOS:     platform.DARWIN,
+			Expected: Folders{
+				{Name: "c", Path: "/c"},
+				{Name: "d", Path: "/c/d"},
+			},
+		},
+		{
+			Case:         "Home directory - git folder",
+			Root:         "~",
+			Relative:     "c/d",
+			GOOS:         platform.DARWIN,
+			GitDir:       &platform.FileInfo{IsDir: true, ParentFolder: "/a/b/c"},
+			GitDirFormat: "<b>%s</b>",
+			Expected: Folders{
+				{Name: "<b>c</b>", Path: "/a/b/c", Display: true},
+				{Name: "d", Path: "/a/b/c/d"},
+			},
+		},
+		{
+			Case:         "Home directory - git folder on Windows",
+			Root:         "C:",
+			Relative:     "a/b/c/d",
+			GOOS:         platform.WINDOWS,
+			GitDir:       &platform.FileInfo{IsDir: true, ParentFolder: "C:/a/b/c"},
+			GitDirFormat: "<b>%s</b>",
+			Expected: Folders{
+				{Name: "a", Path: "C:/a"},
+				{Name: "b", Path: "C:/a/b"},
+				{Name: "<b>c</b>", Path: "C:/a/b/c", Display: true},
+				{Name: "d", Path: "C:/a/b/c/d"},
+			},
+		},
+	}
+
+	for _, tc := range cases {
+		env := new(mock.MockedEnvironment)
+		env.On("PathSeparator").Return("/")
+		env.On("Home").Return("/a/b")
+		env.On("HasParentFilePath", ".git").Return(tc.GitDir, nil)
+		env.On("GOOS").Return(tc.GOOS)
+		path := &Path{
+			env: env,
+			props: properties.Map{
+				GitDirFormat: tc.GitDirFormat,
+			},
+			root:     tc.Root,
+			relative: tc.Relative,
+		}
+		got := path.splitPath()
+		assert.Equal(t, tc.Expected, got, tc.Case)
+	}
+}
